@@ -1,6 +1,5 @@
 use super::SEPARATOR;
-use crate::err_msg;
-use crate::types::SCError;
+use crate::{err_msg, types::StaticSCError};
 use alloc::vec::Vec;
 
 fn hex_digit_to_half_byte(digit: u8) -> Option<u8> {
@@ -104,19 +103,19 @@ impl<'a> HexCallDataDeserializer<'a> {
     }
 
     /// Gets the next argument, deserializes from hex and returns the resulting bytes.
-    pub fn next_argument(&mut self) -> Result<Option<Vec<u8>>, SCError> {
+    pub fn next_argument(&mut self) -> Result<Option<Vec<u8>>, StaticSCError> {
         match self.next_argument_hex() {
             None => Ok(None),
             Some(arg_hex) => {
                 if arg_hex.len() % 2 != 0 {
-                    return Err(SCError::from(err_msg::DESERIALIZATION_ODD_DIGITS));
+                    return Err(StaticSCError::from(err_msg::DESERIALIZATION_ODD_DIGITS));
                 }
                 let res_len = arg_hex.len() / 2;
                 let mut res_vec = Vec::with_capacity(res_len);
                 for i in 0..res_len {
                     match hex_to_byte(arg_hex[2 * i], arg_hex[2 * i + 1]) {
                         None => {
-                            return Err(SCError::from(err_msg::DESERIALIZATION_INVALID_BYTE));
+                            return Err(StaticSCError::from(err_msg::DESERIALIZATION_INVALID_BYTE));
                         },
                         Some(byte) => {
                             res_vec.push(byte);
@@ -242,7 +241,7 @@ mod tests {
         assert_eq!(de.get_func_name(), &b"func"[..]);
         assert_eq!(
             de.next_argument(),
-            Err(SCError::from(err_msg::DESERIALIZATION_ODD_DIGITS))
+            Err(StaticSCError::from(err_msg::DESERIALIZATION_ODD_DIGITS))
         );
         assert_eq!(de.next_argument(), Ok(None));
         assert_eq!(de.next_argument(), Ok(None));
